@@ -129,14 +129,15 @@ def build_argparser():
             help="One or more registry path strings that identify assets  (e.g. hg38/fasta or hg38/fasta:tag"
                  + (" or hg38/fasta.fai:tag)." if cmd == GET_ASSET_CMD else ")."))
 
+    for cmd in [PULL_CMD, REMOVE_CMD, INSERT_CMD]:
+        sps[cmd].add_argument(
+            "-f", "--force", action="store_true",
+            help="Do not prompt before action, approve upfront.")
+
     sps[PULL_CMD].add_argument(
         "-u", "--no-untar", action="store_true",
         help="Do not extract tarballs.")
 
-    sps[REMOVE_CMD].add_argument(
-        "-f", "--force", action="store_true",
-        help="Do not prompt before removal, approve.")
-
     sps[INSERT_CMD].add_argument(
         "-p", "--path", required=True,
         help="Relative local path to asset.")
@@ -236,26 +237,35 @@ def get_asset_vars(genome, asset_key, tag, outfolder, specific_args=None, specif
     return asset_vars
 
 
-def refgenie_add(rgc, asset_dict, path):
+def refgenie_add(rgc, asset_dict, path, force=False):
     """
     Add an external asset to the config.
-    File existence is checked and asset files are transferred to the selected tag subdirectory
+    File existence is checked and asset files are transferred to the selected
+    tag subdirectory
 
     :param refgenconf.RefGenConf rgc: genome configuration object
     :param dict asset_dict: a single parsed registry path
-    :param str path: the path provided by the user. Must be relative to the specific genome directory
+    :param str path: the path provided by the user. Must be relative to the
+        specific genome directory
+    :param bool force: whether the replacement of a possibly existing asset
+        should be forced
     """
     # remove the first directory from the provided path if it is the genome name
-    path = os.path.join(*path.split(os.sep)[1:]) if path.split(os.sep)[0] == asset_dict["genome"] else path
-    tag = asset_dict["tag"] or rgc.get_default_tag(asset_dict["genome"], asset_dict["asset"])
-    outfolder = os.path.abspath(os.path.join(rgc[CFG_FOLDER_KEY], asset_dict["genome"]))
+    path = os.path.join(*path.split(os.sep)[1:]) \
+        if path.split(os.sep)[0] == asset_dict["genome"] else path
+    tag = asset_dict["tag"] \
+          or rgc.get_default_tag(asset_dict["genome"], asset_dict["asset"])
+    outfolder = \
+        os.path.abspath(os.path.join(rgc[CFG_FOLDER_KEY], asset_dict["genome"]))
     abs_asset_path = os.path.join(outfolder, path)
     if asset_dict["seek_key"] is None:
-        # if seek_key is not specified we're about to move a directory to the tag subdir
+        # if seek_key is not specified we're about to move a directory to
+        # the tag subdir
         tag_path = os.path.join(abs_asset_path, tag)
         from shutil import copytree as cp
     else:
-        # if seek_key is specified we're about to move just a single file to the tag subdir
+        # if seek_key is specified we're about to move just a single file to
+        # he tag subdir
         tag_path = os.path.join(os.path.dirname(abs_asset_path), tag)
         if not os.path.exists(tag_path):
             os.makedirs(tag_path)
@@ -264,24 +274,32 @@ def refgenie_add(rgc, asset_dict, path):
         if not os.path.exists(tag_path):
             cp(abs_asset_path, tag_path)
         else:
-            if not query_yes_no("Path '{}' exists. Do you want to overwrite?".format(tag_path)):
+            if not force and not \
+                    query_yes_no("Path '{}' exists. Do you want to overwrite?".
+                                         format(tag_path)):
                 return False
             else:
                 _remove(tag_path)
                 cp(abs_asset_path, tag_path)
     else:
-        raise OSError("Absolute path '{}' does not exist. The provided path must be relative to: {}".
+        raise OSError("Absolute path '{}' does not exist. "
+                      "The provided path must be relative to: {}".
                       format(abs_asset_path, rgc[CFG_FOLDER_KEY]))
     rgc.make_writable()
     gat_bundle = [asset_dict["genome"], asset_dict["asset"], tag]
-    rgc.update_tags(*gat_bundle,
-                    data={CFG_ASSET_PATH_KEY: path if os.path.isdir(abs_asset_path) else os.path.dirname(path)})
+    td = {CFG_ASSET_PATH_KEY:
+              path if os.path.isdir(abs_asset_path) else os.path.dirname(path)}
+    rgc.update_tags(*gat_bundle, data=td)
     # seek_key points to the entire dir if not specified
-    seek_key_value = os.path.basename(abs_asset_path) if asset_dict["seek_key"] is not None else "."
-    rgc.update_seek_keys(*gat_bundle, keys={asset_dict["seek_key"] or asset_dict["asset"]: seek_key_value})
+    seek_key_value = os.path.basename(abs_asset_path) \
+        if asset_dict["seek_key"] is not None else "."
+    sk = {asset_dict["seek_key"] or asset_dict["asset"]: seek_key_value}
+    rgc.update_seek_keys(*gat_bundle, keys=sk)
     rgc.set_default_pointer(asset_dict["genome"], asset_dict["asset"], tag)
-    # a separate update_tags call since we want to use the get_asset method that requires a complete asset entry in rgc
-    rgc.update_tags(*gat_bundle, data={CFG_ASSET_CHECKSUM_KEY: get_dir_digest(_seek(rgc, *gat_bundle))})
+    # a separate update_tags call since we want to use the get_asset method
+    # that requires a complete asset entry in rgc
+    td = {CFG_ASSET_CHECKSUM_KEY: get_dir_digest(_seek(rgc, *gat_bundle))}
+    rgc.update_tags(*gat_bundle, data=td)
     # Write the updated refgenie genome configuration
     rgc.write()
     rgc.make_readonly()
@@ -635,10 +653,11 @@ def main():
         if len(asset_list) > 1:
             raise NotImplementedError("Can only add 1 asset at a time")
         else:
-            refgenie_add(rgc, asset_list[0], args.path)
+            refgenie_add(rgc, asset_list[0], args.path, args.force)
 
     elif args.command == PULL_CMD:
         rgc = RefGenConf(filepath=gencfg, writable=False)
+        force = None if not args.force else True
         outdir = rgc[CFG_FOLDER_KEY]
         if not os.path.exists(outdir):
             raise MissingFolderError(outdir)
@@ -651,7 +670,8 @@ def main():
             return
 
         for a in asset_list:
-            rgc.pull(a["genome"], a["asset"], a["tag"],unpack=not args.no_untar)
+            rgc.pull(a["genome"], a["asset"], a["tag"],
+                     unpack=not args.no_untar, force=force)
 
     elif args.command in [LIST_LOCAL_CMD, LIST_REMOTE_CMD]:
         rgc = RefGenConf(filepath=gencfg, writable=False)
@@ -707,8 +727,6 @@ def main():
                     _LOGGER.info("Removed an incomplete asset '{}/{}:{}'".
                                  format(*bundle))
                     return
-                else:
-                    _seek(rgc, *bundle, enclosing_dir=True)
             except (KeyError, MissingAssetError, MissingGenomeError):
                 _LOGGER.info("Asset '{}/{}:{}' does not exist".format(*bundle))
                 return
